==> haskell-network-multicast-0.3.2-301-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-multicast.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-multicast
version:              0.3.2
visibility:           public
id:                   network-multicast-0.3.2-66rDee5eXUyGA3xeI1tKAK
key:                  network-multicast-0.3.2-66rDee5eXUyGA3xeI1tKAK
license:              LicenseRef-PublicDomain
copyright:            2008-2019 Audrey Tang
maintainer:           Marco Zocca
author:               Audrey Tang <audreyt@audreyt.org>
stability:            experimental
synopsis:             Simple multicast library
description:
    The "Network.Multicast" module is for sending
    UDP datagrams over multicast (class D) addresses.

category:             Network
abi:                  cd399b4d8758b321d9c822fbe18abe78
exposed:              True
exposed-modules:      Network.Multicast
import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-multicast-0.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-multicast-0.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-multicast-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-multicast
hs-libraries:         HSnetwork-multicast-0.3.2-66rDee5eXUyGA3xeI1tKAK
depends:
    base-4.17.2.1 network-3.1.4.0-4cEUA9pnnvEEvGlZk2FqT
    network-bsd-2.8.1.0-L5HEmsOfUJdFzoiASssZR1

haddock-interfaces:
    /usr/share/doc/haskell-network-multicast/html/network-multicast.haddock

haddock-html:         /usr/share/doc/haskell-network-multicast/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-multicast-0.3.2-302-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-multicast.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-multicast
version:              0.3.2
visibility:           public
id:                   network-multicast-0.3.2-LH9GKUDrN0DVy2BaOa8mb
key:                  network-multicast-0.3.2-LH9GKUDrN0DVy2BaOa8mb
license:              LicenseRef-PublicDomain
copyright:            2008-2019 Audrey Tang
maintainer:           Marco Zocca
author:               Audrey Tang <audreyt@audreyt.org>
stability:            experimental
synopsis:             Simple multicast library
description:
    The "Network.Multicast" module is for sending
    UDP datagrams over multicast (class D) addresses.

category:             Network
abi:                  47487aeb37f8816c4f593315e3f5ec01
exposed:              True
exposed-modules:      Network.Multicast
import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-multicast-0.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-multicast-0.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-multicast-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-multicast
hs-libraries:         HSnetwork-multicast-0.3.2-LH9GKUDrN0DVy2BaOa8mb
depends:
    base-4.17.2.1 network-3.1.4.0-4UbSgXPdAp7DQ7Pftr1aPB
    network-bsd-2.8.1.0-AdZ7q19Usvj4P8px7xbjon

haddock-interfaces:
    /usr/share/doc/haskell-network-multicast/html/network-multicast.haddock

haddock-html:         /usr/share/doc/haskell-network-multicast/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
